Third Party Software
====================

The geoh5py repository and source distributions bundle several libraries that are
compatibly licensed.  We list these here.

.. list-table::
  :widths: 30 30 60
  :header-rows: 1

  * - Name
    - License
    - Description
  * - `h5py <http://www.h5py.org>`_
    - BSD-3-Clause
    - Read and write HDF5 files from Python.
  * - `NumPy <https://github.com/numpy/numpy>`_
    - BSD-3-Clause
    - NumPy is the fundamental package for array computing with Python.
  * - `Pydantic <https://docs.pydantic.dev>`_
    - MIT
    - Data validation using Python type hints.
  * - `Pillow <https://github.com/python-pillow/Pillow>`_
    - HPND
    - Python Imaging Library (Fork)
